==> foundation-2.6.1.tgz: package/Paypal/Paypal.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Paypal = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M33.469 70.372l2.732-11.775c.365-1.647 2.06-3.01 3.779-3.01h2.267c9.698-.01 17.22-1.993 22.626-5.965 5.398-3.963 8.098-9.217 8.085-15.714.013-2.854-.481-5.241-1.512-7.148-.985-1.923-2.463-3.484-4.349-4.663-1.956-1.207-4.231-2.039-6.883-2.54-2.668-.479-5.784-.714-9.359-.746l-16.554.013c-1.72.02-3.406 1.369-3.803 3.022L19.335 70.372c-.384 1.66.69 3.032 2.404 3.032h7.931c1.714 0 3.413-1.336 3.799-3.032zm6.486-28.161l2.387-10.287c.364-1.657 2.073-3.031 3.787-3.016l2.595-.016c3.031 0 5.335.519 6.89 1.551 1.532 1.004 2.311 2.589 2.284 4.722.045 3.211-1.172 5.696-3.575 7.45-2.391 1.748-5.705 2.624-10.006 2.624h-1.944c-1.714 0-2.796-1.359-2.418-3.028z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M79.23 34.544c-.986-1.923-2.463-3.484-4.349-4.663-.142-.087-.289-.168-.434-.252.055.101.115.198.167.301 1.031 1.906 1.525 4.295 1.512 7.148.013 6.497-2.687 11.751-8.085 15.714-5.406 3.971-12.928 5.955-22.627 5.964H43.15c-1.719 0-3.414 1.363-3.779 3.01l-2.732 11.776c-.385 1.696-2.084 3.032-3.799 3.032h-5.356l-.364 1.582c-.384 1.66.691 3.033 2.404 3.033h7.93c1.715 0 3.414-1.337 3.799-3.033l2.733-11.775c.365-1.646 2.06-3.01 3.779-3.01h2.267c9.698-.01 17.22-1.993 22.626-5.965 5.398-3.963 8.098-9.217 8.084-15.713.014-2.853-.481-5.242-1.512-7.149z"
  }));
});
Paypal.displayName = 'Paypal';
export const PaypalDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Paypal/Paypal.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Paypal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M33.469 70.372l2.732-11.775c.365-1.647 2.06-3.01 3.779-3.01h2.267c9.698-.01 17.22-1.993 22.626-5.965 5.398-3.963 8.098-9.217 8.085-15.714.013-2.854-.481-5.241-1.512-7.148-.985-1.923-2.463-3.484-4.349-4.663-1.956-1.207-4.231-2.039-6.883-2.54-2.668-.479-5.784-.714-9.359-.746l-16.554.013c-1.72.02-3.406 1.369-3.803 3.022L19.335 70.372c-.384 1.66.69 3.032 2.404 3.032h7.931c1.714 0 3.413-1.336 3.799-3.032zm6.486-28.161l2.387-10.287c.364-1.657 2.073-3.031 3.787-3.016l2.595-.016c3.031 0 5.335.519 6.89 1.551 1.532 1.004 2.311 2.589 2.284 4.722.045 3.211-1.172 5.696-3.575 7.45-2.391 1.748-5.705 2.624-10.006 2.624h-1.944c-1.714 0-2.796-1.359-2.418-3.028z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M79.23 34.544c-.986-1.923-2.463-3.484-4.349-4.663-.142-.087-.289-.168-.434-.252.055.101.115.198.167.301 1.031 1.906 1.525 4.295 1.512 7.148.013 6.497-2.687 11.751-8.085 15.714-5.406 3.971-12.928 5.955-22.627 5.964H43.15c-1.719 0-3.414 1.363-3.779 3.01l-2.732 11.776c-.385 1.696-2.084 3.032-3.799 3.032h-5.356l-.364 1.582c-.384 1.66.691 3.033 2.404 3.033h7.93c1.715 0 3.414-1.337 3.799-3.033l2.733-11.775c.365-1.646 2.06-3.01 3.779-3.01h2.267c9.698-.01 17.22-1.993 22.626-5.965 5.398-3.963 8.098-9.217 8.084-15.713.014-2.853-.481-5.242-1.512-7.149z"
  }));
});
Paypal.displayName = 'Paypal';
export var PaypalDimensions = {
  height: 100,
  width: 100
};
